.. AUTO-GENERATED FILE -- DO NOT EDIT!

core.device
===========

Module: :mod:`core.device`
--------------------------
.. automodule:: zmq.core.device

.. currentmodule:: zmq.core.device

.. autofunction:: zmq.core.device.device

